
/* Generated data (by glib-mkenums) */

#ifndef __THUNAR_VFS_ENUM_TYPES_H__
#define __THUNAR_VFS_ENUM_TYPES_H__
#include <exo/exo.h>
G_BEGIN_DECLS
/* enumerations from "thunar-vfs-job.h" */
GType thunar_vfs_job_response_get_type (void) G_GNUC_CONST;
#define THUNAR_VFS_TYPE_VFS_JOB_RESPONSE (thunar_vfs_job_response_get_type())
/* enumerations from "thunar-vfs-mime-handler.h" */
GType thunar_vfs_mime_handler_flags_get_type (void) G_GNUC_CONST;
#define THUNAR_VFS_TYPE_VFS_MIME_HANDLER_FLAGS (thunar_vfs_mime_handler_flags_get_type())
/* enumerations from "thunar-vfs-monitor.h" */
GType thunar_vfs_monitor_event_get_type (void) G_GNUC_CONST;
#define THUNAR_VFS_TYPE_VFS_MONITOR_EVENT (thunar_vfs_monitor_event_get_type())
/* enumerations from "thunar-vfs-thumb.h" */
GType thunar_vfs_thumb_size_get_type (void) G_GNUC_CONST;
#define THUNAR_VFS_TYPE_VFS_THUMB_SIZE (thunar_vfs_thumb_size_get_type())
/* enumerations from "thunar-vfs-types.h" */
GType thunar_vfs_deep_count_flags_get_type (void) G_GNUC_CONST;
#define THUNAR_VFS_TYPE_VFS_DEEP_COUNT_FLAGS (thunar_vfs_deep_count_flags_get_type())
GType thunar_vfs_file_type_get_type (void) G_GNUC_CONST;
#define THUNAR_VFS_TYPE_VFS_FILE_TYPE (thunar_vfs_file_type_get_type())
GType thunar_vfs_file_mode_get_type (void) G_GNUC_CONST;
#define THUNAR_VFS_TYPE_VFS_FILE_MODE (thunar_vfs_file_mode_get_type())
GType thunar_vfs_file_flags_get_type (void) G_GNUC_CONST;
#define THUNAR_VFS_TYPE_VFS_FILE_FLAGS (thunar_vfs_file_flags_get_type())
/* enumerations from "thunar-vfs-volume.h" */
GType thunar_vfs_volume_kind_get_type (void) G_GNUC_CONST;
#define THUNAR_VFS_TYPE_VFS_VOLUME_KIND (thunar_vfs_volume_kind_get_type())
GType thunar_vfs_volume_status_get_type (void) G_GNUC_CONST;
#define THUNAR_VFS_TYPE_VFS_VOLUME_STATUS (thunar_vfs_volume_status_get_type())
G_END_DECLS

#endif /* !__THUNAR_VFS_ENUM_TYPES_H__ */

/* Generated data ends here */

